@@ -7,15 +7,15 @@
 #include "application.h"
 #include "main_dlg.h"
 #include <zen/file_access.h>
-#include <zen/thread.h>
+//#include <zen/thread.h>
 #include <zen/shutdown.h>
 #include <zen/resolve_path.h>
 #include <wx/clipbrd.h>
 #include <wx/event.h>
-#include <wx/log.h>
+//#include <wx/log.h>
 #include <wx/tooltip.h>
 #include <wx+/app_main.h>
-#include <wx+/popup_dlg.h>
+//#include <wx+/popup_dlg.h>
 #include <wx+/image_resources.h>
 #include "config.h"
 #include "../localization.h"
@@ -204,7 +204,7 @@ int Application::OnExit()
 }
 
 
-wxLayoutDirection Application::GetLayoutDirection() const { return fff::getLayoutDirection(); }
+wxLayoutDirection Application::GetLayoutDirection() const { return languageLayoutIsRtl() ? wxLayout_RightToLeft : wxLayout_LeftToRight; }
 
 
 int Application::OnRun()
