@@ -13,12 +13,12 @@
 
 namespace rts
 {
-enum class AbortReason
+enum class CancelReason
 {
-    REQUEST_GUI,
-    REQUEST_EXIT
+    requestGui,
+    requestExit
 };
-AbortReason runFolderMonitor(const XmlRealConfig& config, const wxString& jobname); //jobname may be empty
+CancelReason runFolderMonitor(const XmlRealConfig& config, const wxString& jobname); //jobname may be empty
 }
 
 #endif //TRAY_MENU_H_3967857420987534253245
