@@ -8,9 +8,9 @@
 #include <bit> //std::endian
 #include <zen/guid.h>
 #include <zen/crc.h>
-#include <zen/build_info.h>
+//#include <zen/build_info.h>
 #include <zen/zlib_wrap.h>
-#include "../afs/concrete.h"
+//#include "../afs/concrete.h"
 #include "../afs/native.h"
 #include "status_handler_impl.h"
 
@@ -55,7 +55,7 @@ AbstractPath getDatabaseFilePath(const BaseFolderPair& baseFolder)
         - precomposed/decomposed UTF: differences already ignored
         - 32 vs 64-bit: already handled
 
-        => give db files different names:                   */
+        => give DB files different names:                   */
     const Zstring dbName = Zstr(".sync"); //files beginning with dots are usually hidden
     return AFS::appendRelPath(baseFolder.getAbstractPath<side>(), dbName + SYNC_DB_FILE_ENDING);
 }
