@@ -7,9 +7,7 @@
 #ifndef MULTI_RENAME_H_489572039485723453425
 #define MULTI_RENAME_H_489572039485723453425
 
-//#include <span>
-//#include <string>
-//#include <vector>
+#include <string>
 #include <zen/stl_tools.h>
 
 namespace fff
@@ -18,6 +16,8 @@ struct RenameBuf;
 
 std::pair<std::wstring /*phrase*/, zen::SharedRef<const RenameBuf>> getPlaceholderPhrase(const std::vector<std::wstring>& strings);
 const std::vector<std::wstring> resolvePlaceholderPhrase(const std::wstring_view phrase, const RenameBuf& buf);
+
+bool isRenamePlaceholderChar(wchar_t c);
 }
 
 #endif //MULTI_RENAME_H_489572039485723453425
