@@ -6,7 +6,7 @@
 
 #include "parallel_scan.h"
 #include <chrono>
-#include <zen/file_error.h>
+//#include <zen/file_error.h>
 #include <zen/thread.h>
 #include <zen/scope_guard.h>
 
