@@ -6,13 +6,13 @@
 
 #include "batch_config.h"
 #include <wx/wupdlock.h>
-#include <wx+/window_layout.h>
+//#include <wx+/window_layout.h>
 #include <wx+/image_resources.h>
 #include <wx+/image_tools.h>
 #include <wx+/choice_enum.h>
 #include <wx+/popup_dlg.h>
 #include "gui_generated.h"
-#include "folder_selector.h"
+//#include "folder_selector.h"
 
 
 using namespace zen;
@@ -83,7 +83,7 @@ BatchDialog::BatchDialog(wxWindow* parent, BatchDialogConfig& dlgCfg) :
     GetSizer()->SetSizeHints(this); //~=Fit() + SetMinSize()
 #ifdef __WXGTK3__
     Show(); //GTK3 size calculation requires visible window: https://github.com/wxWidgets/wxWidgets/issues/16088
-    Hide(); //avoid old position flash when Center() moves window (asynchronously?)
+    //Hide(); -> avoids old position flash before Center() on GNOME but causes hang on KDE? https://freefilesync.org/forum/viewtopic.php?t=10103#p42404
 #endif
     Center(); //needs to be re-applied after a dialog size change!
 
