@@ -7,7 +7,6 @@
 #ifndef GRID_VIEW_H_9285028345703475842569
 #define GRID_VIEW_H_9285028345703475842569
 
-#include <span>
 #include <vector>
 #include <variant>
 #include <unordered_map>
@@ -22,7 +21,7 @@ class FileView //grid view of FolderComparison
 {
 public:
     FileView() {}
-    explicit FileView(FolderComparison& folderCmp); //takes (shared) ownership
+    explicit FileView(FolderComparison& folderCmp); //takes weak (non-owning) references
 
     size_t rowsOnView() const { return viewRef_  .size(); } //only visible elements
     size_t rowsTotal () const { return sortedRef_.size(); } //total rows available
