@@ -32,9 +32,10 @@ public:
 
     void     initNewPhase    (int itemsTotal, int64_t bytesTotal, ProcessPhase phaseID) override; //
     void     logMessage      (const std::wstring& msg, MsgType type)                    override; //
-    void     reportWarning   (const std::wstring& msg, bool& warningActive)             override; //throw AbortProcess
+    void     reportWarning   (const std::wstring& msg, bool& warningActive)             override; //throw CancelProcess
     Response reportError     (const ErrorInfo& errorInfo)                               override; //
     void     reportFatalError(const std::wstring& msg)                                  override; //
+    ErrorStats getErrorStats() const override;
 
     void forceUiUpdateNoThrow() override;
 
@@ -43,7 +44,7 @@ public:
         ProcessSummary summary;
         zen::SharedRef<const zen::ErrorLog> errorLog;
     };
-    Result reportResults(); //noexcept!!
+    Result prepareResult(); //noexcept!!
 
 private:
     void onLocalKeyEvent(wxKeyEvent& event);
@@ -52,12 +53,14 @@ private:
 
     MainDialog& mainDlg_;
     zen::ErrorLog errorLog_;
+    mutable Statistics::ErrorStats errorStatsBuf_{};
+    mutable size_t errorStatsRowsChecked_ = 0;
     const bool ignoreErrors_;
     const size_t autoRetryCount_;
     const std::chrono::seconds autoRetryDelay_;
     const Zstring soundFileAlertPending_;
     const std::chrono::system_clock::time_point startTime_;
-    const std::chrono::steady_clock::time_point startTimeSteady_ = std::chrono::steady_clock::now();
+    const std::chrono::steady_clock::time_point panelInitTime_ = std::chrono::steady_clock::now();
 };
 
 
@@ -73,39 +76,40 @@ public:
                                 std::chrono::seconds autoRetryDelay,
                                 const Zstring& soundFileSyncComplete,
                                 const Zstring& soundFileAlertPending,
-                                const wxSize& progressDlgSize, bool dlgMaximize,
-                                bool autoCloseDialog,
-                                const zen::ErrorLog* errorLogStart /*optional*/); //noexcept!
+                                const zen::WindowLayout::Dimensions& dim,
+                                bool autoCloseDialog); //noexcept!
     ~StatusHandlerFloatingDialog();
 
     void     initNewPhase    (int itemsTotal, int64_t bytesTotal, ProcessPhase phaseID) override; //
     void     logMessage      (const std::wstring& msg, MsgType type)                    override; //
-    void     reportWarning   (const std::wstring& msg, bool& warningActive)             override; //throw AbortProcess
+    void     reportWarning   (const std::wstring& msg, bool& warningActive)             override; //throw CancelProcess
     Response reportError     (const ErrorInfo& errorInfo)                               override; //
     void     reportFatalError(const std::wstring& msg)                                  override; //
+    ErrorStats getErrorStats() const override;
 
     void updateDataProcessed(int itemsDelta, int64_t bytesDelta) override; //noexcept!!
     void forceUiUpdateNoThrow()                                  override; //
 
+    struct Result
+    {
+        ProcessSummary summary;
+        zen::SharedRef<zen::ErrorLog> errorLog;
+    };
+    Result prepareResult();
+
     enum class FinalRequest
     {
         none,
         exit,
         shutdown
     };
-    struct Result
+    struct DlgOptions
     {
-        ProcessSummary summary;
-        zen::SharedRef<const zen::ErrorLog> errorLog;
+        bool autoCloseSelected;
+        zen::WindowLayout::Dimensions dim;
         FinalRequest finalRequest;
-        AbstractPath logFilePath;
-        wxSize dlgSize;
-        bool dlgIsMaximized;
-        bool autoCloseDialog;
     };
-    Result reportResults(const Zstring& postSyncCommand, PostSyncCondition postSyncCondition,
-                         const AbstractPath& logFolderPath, int logfilesMaxAgeDays, LogFileFormat logFormat, const std::set<AbstractPath>& logFilePathsToKeep,
-                         const std::string& emailNotifyAddress, ResultsNotification emailNotifyCondition); //noexcept!!
+    DlgOptions showResult();
 
 private:
     const std::vector<std::wstring> jobNames_;
@@ -115,7 +119,10 @@ private:
     const Zstring soundFileSyncComplete_;
     const Zstring soundFileAlertPending_;
     SyncProgressDialog* progressDlg_; //managed to have the same lifetime as this handler!
-    zen::ErrorLog errorLog_;
+    zen::SharedRef<zen::ErrorLog> errorLog_ = zen::makeSharedRef<zen::ErrorLog>();
+    mutable Statistics::ErrorStats errorStatsBuf_{};
+    mutable size_t errorStatsRowsChecked_ = 0;
+    std::optional<TaskResult> syncResult_;
 };
 }
 
