@@ -17,9 +17,8 @@
 #include <wx+/window_layout.h>
 #include <wx+/popup_dlg.h>
 #include <wx+/image_resources.h>
-#include <wx+/window_tools.h>
 #include "gui_generated.h"
-#include "command_box.h"
+//#include "command_box.h"
 #include "folder_selector.h"
 #include "../base/norm_filter.h"
 #include "../base/file_hierarchy.h"
@@ -709,7 +708,7 @@ globalLogFolderPhrase_(globalLogFolderPhrase)
     GetSizer()->SetSizeHints(this); //~=Fit() + SetMinSize()
 #ifdef __WXGTK3__
     Show(); //GTK3 size calculation requires visible window: https://github.com/wxWidgets/wxWidgets/issues/16088
-    Hide(); //avoid old position flash when Center() moves window (asynchronously?)
+    //Hide(); -> avoids old position flash before Center() on GNOME but causes hang on KDE? https://freefilesync.org/forum/viewtopic.php?t=10103#p42404
 #endif
     Center(); //needs to be re-applied after a dialog size change!
 
