@@ -9,7 +9,8 @@
 
 #include <functional>
 #include <memory>
-#include <wx/image.h>
+#include <wx/string.h>
+//#include <wx/image.h>
 
 
 /*  show tray icon with progress during lifetime of this instance
