@@ -5,11 +5,9 @@
 // *****************************************************************************
 
 #include "curl_wrap.h"
-#include <zen/sys_info.h>
 #include <zen/http.h>
 #include <zen/open_ssl.h>
 #include <zen/thread.h>
-#include <zen/file_path.h>
     #include <fcntl.h>
 
 using namespace zen;
@@ -253,6 +251,8 @@ HttpSession::Result HttpSession::perform(const std::string& serverRelPath,
     headers = ::curl_slist_append(headers, "Expect:"); //guess, what: www.googleapis.com doesn't support it! e.g. gdriveUploadFile()
     //CURLOPT_EXPECT_100_TIMEOUT_MS: should not be needed
 
+    //CURLOPT_TCP_NODELAY => already set by default https://brooker.co.za/blog/2024/05/09/nagle.html
+
     if (headers)
         setCurlOption({CURLOPT_HTTPHEADER, headers}); //throw SysError
     //---------------------------------------------------
@@ -401,9 +401,11 @@ std::wstring zen::formatCurlStatusCode(CURLcode sc)
             ZEN_CHECK_CASE_FOR_CONSTANT(CURLE_PROXY);
             ZEN_CHECK_CASE_FOR_CONSTANT(CURLE_SSL_CLIENTCERT);
             ZEN_CHECK_CASE_FOR_CONSTANT(CURLE_UNRECOVERABLE_POLL);
+            ZEN_CHECK_CASE_FOR_CONSTANT(CURLE_TOO_LARGE);
+            ZEN_CHECK_CASE_FOR_CONSTANT(CURLE_ECH_REQUIRED);
             ZEN_CHECK_CASE_FOR_CONSTANT(CURL_LAST);
     }
-    static_assert(CURL_LAST == CURLE_UNRECOVERABLE_POLL + 1);
+    static_assert(CURL_LAST == CURLE_ECH_REQUIRED + 1);
 
     return replaceCpy<std::wstring>(L"Curl status %x", L"%x", numberTo<std::wstring>(static_cast<int>(sc)));
 }
