@@ -9,10 +9,10 @@
 
 #include <unordered_map>
 #include <optional>
-#include <zen/basic_math.h>
+//#include <zen/basic_math.h>
 #include <wx/dcbuffer.h> //for macro: wxALWAYS_NATIVE_DOUBLE_BUFFER
 #include <wx/dcscreen.h>
-#include <wx/bmpbndl.h>
+//#include <wx/bmpbndl.h>
     //    #include <gtk/gtk.h>
 
 
@@ -195,8 +195,12 @@ public:
         }
         else
         {
-            dc_.SetClippingRegion(r);
-            clippingAreas_.emplace(&dc_, r);
+            //caveat: actual clipping region is smaller when rect is not fully inside the DC
+            //=> ensure consistency for validateClippingBuffer()
+            const wxRect tmp = getIntersection(r, wxRect(dc.GetSize()));
+
+            dc_.SetClippingRegion(tmp);
+            clippingAreas_.emplace(&dc_, tmp);
         }
     }
 
