@@ -5,10 +5,11 @@
 // *****************************************************************************
 
 #include "dir_watcher.h"
-#include <algorithm>
-#include <set>
+//#include <algorithm>
+//#include <set>
 #include "thread.h"
 #include "scope_guard.h"
+    #include "file_access.h"
 
     #include <map>
     #include <sys/inotify.h>
