@@ -58,8 +58,7 @@ FileBase::~FileBase()
         {
             close(); //throw FileError
         }
-        catch (FileError&) { assert(false); }
-    warn_static("log it!")
+        catch (const FileError& e) { logExtraError(e.toString()); }
 }
 
 
@@ -71,7 +70,7 @@ void FileBase::close() //throw FileError
             throw SysError(L"Contract error: close() called more than once.");
         if (::close(hFile_) != 0)
             THROW_LAST_SYS_ERROR("close");
-        hFile_ = invalidFileHandle; //do NOT set on failure! => ~FileOutputPlain() still wants to (try to) delete the file!
+        hFile_ = invalidFileHandle; //do NOT set on error! => ~FileOutputPlain() still wants to (try to) delete the file!
     }
     catch (const SysError& e) { throw FileError(replaceCpy(_("Cannot write file %x."), L"%x", fmtPath(getFilePath())), e.toString()); }
 }
@@ -153,7 +152,7 @@ FileInputPlain::FileInputPlain(FileHandle handle, const Zstring& filePath) :
 size_t FileInputPlain::tryRead(void* buffer, size_t bytesToRead) //throw FileError, ErrorFileLocked
 {
     if (bytesToRead == 0) //"read() with a count of 0 returns zero" => indistinguishable from end of file! => check!
-        throw std::logic_error("Contract violation! " + std::string(__FILE__) + ':' + numberTo<std::string>(__LINE__));
+        throw std::logic_error(std::string(__FILE__) + '[' + numberTo<std::string>(__LINE__) + "] Contract violation!");
     assert(bytesToRead % getBlockSize() == 0);
     try
     {
@@ -170,8 +169,7 @@ size_t FileInputPlain::tryRead(void* buffer, size_t bytesToRead) //throw FileErr
         if (bytesRead < 0)
             THROW_LAST_SYS_ERROR("read");
 
-        if (makeUnsigned(bytesRead) > bytesToRead) //better safe than sorry
-            throw SysError(formatSystemError("read", L"", L"Buffer overflow."));
+        ASSERT_SYSERROR(makeUnsigned(bytesRead) <= bytesToRead); //better safe than sorry
         return bytesRead; //"zero indicates end of file"
     }
     catch (const SysError& e) { throw FileError(replaceCpy(_("Cannot read file %x."), L"%x", fmtPath(getFilePath())), e.toString()); }
@@ -229,10 +227,9 @@ FileOutputPlain::~FileOutputPlain()
             if (::unlink(getFilePath().c_str()) != 0)
                 THROW_LAST_SYS_ERROR("unlink");
         }
-        catch (const SysError&)
+        catch (const SysError& e)
         {
-            assert(false);
-            warn_static("at least log on failure!")
+            logExtraError(replaceCpy(_("Cannot delete file %x."), L"%x", fmtPath(getFilePath())) + L"\n\n" + e.toString());
         }
 }
 
@@ -245,6 +242,11 @@ void FileOutputPlain::reserveSpace(uint64_t expectedSize) //throw FileError
 
     try
     {
+#if 0 /*  fallocate(FALLOC_FL_KEEP_SIZE):
+            - perf: no real benefit (in a quick and dirty local test)
+            - breaks Btrfs compression: https://freefilesync.org/forum/viewtopic.php?t=10356
+            - apparently not even used by cp: https://github.com/coreutils/coreutils/blob/17479ef60c8edbd2fe8664e31a7f69704f0cd221/src/copy.c#LL1234C5-L1234C5      */
+
         //don't use ::posix_fallocate which uses horribly inefficient fallback if FS doesn't support it (EOPNOTSUPP) and changes files size!
         //FALLOC_FL_KEEP_SIZE => allocate only, file size is NOT changed!
         if (::fallocate(getHandle(),         //int fd
@@ -253,6 +255,7 @@ void FileOutputPlain::reserveSpace(uint64_t expectedSize) //throw FileError
                         expectedSize) != 0)  //off_t len
             if (errno != EOPNOTSUPP) //possible, unlike with posix_fallocate()
                 THROW_LAST_SYS_ERROR("fallocate");
+#endif
 
     }
     catch (const SysError& e) { throw FileError(replaceCpy(_("Cannot write file %x."), L"%x", fmtPath(getFilePath())), e.toString()); }
@@ -263,7 +266,7 @@ void FileOutputPlain::reserveSpace(uint64_t expectedSize) //throw FileError
 size_t FileOutputPlain::tryWrite(const void* buffer, size_t bytesToWrite) //throw FileError
 {
     if (bytesToWrite == 0)
-        throw std::logic_error("Contract violation! " + std::string(__FILE__) + ':' + numberTo<std::string>(__LINE__));
+        throw std::logic_error(std::string(__FILE__) + '[' + numberTo<std::string>(__LINE__) + "] Contract violation!");
     assert(bytesToWrite % getBlockSize() == 0 || bytesToWrite < getBlockSize());
     try
     {
@@ -283,8 +286,8 @@ size_t FileOutputPlain::tryWrite(const void* buffer, size_t bytesToWrite) //thro
 
             THROW_LAST_SYS_ERROR("write");
         }
-        if (makeUnsigned(bytesWritten) > bytesToWrite) //better safe than sorry
-            throw SysError(formatSystemError("write", L"", L"Buffer overflow."));
+
+        ASSERT_SYSERROR(makeUnsigned(bytesWritten) <= bytesToWrite); //better safe than sorry
         return bytesWritten;
     }
     catch (const SysError& e) { throw FileError(replaceCpy(_("Cannot write file %x."), L"%x", fmtPath(getFilePath())), e.toString()); }
@@ -306,7 +309,7 @@ std::string zen::getFileContent(const Zstring& filePath, const IoCallback& notif
 }
 
 
-void zen::setFileContent(const Zstring& filePath, const std::string& byteStream, const IoCallback& notifyUnbufferedIO /*throw X*/) //throw FileError, X
+void zen::setFileContent(const Zstring& filePath, const std::string_view byteStream, const IoCallback& notifyUnbufferedIO /*throw X*/) //throw FileError, X
 {
     const Zstring tmpFilePath = getPathWithTempName(filePath);
 
@@ -324,9 +327,8 @@ void zen::setFileContent(const Zstring& filePath, const std::string& byteStream,
 
     tmpFile.close(); //throw FileError
     //take over ownership:
-    ZEN_ON_SCOPE_FAIL( try { removeFilePlain(tmpFilePath); /*throw FileError*/ }
-    catch (FileError&) {});
-    warn_static("log it!")
+    ZEN_ON_SCOPE_FAIL( try { removeFilePlain(tmpFilePath); }
+    catch (const FileError& e) { logExtraError(e.toString()); });
 
     //operation finished: move temp file transactionally
     moveAndRenameItem(tmpFilePath, filePath, true /*replaceExisting*/); //throw FileError, (ErrorMoveUnsupported), (ErrorTargetExisting)
