@@ -10,7 +10,7 @@
 #include <wx/app.h>
 #include <wx/display.h>
 #include <wx/sound.h>
-#include "app_main.h"
+//#include "app_main.h"
 #include "bitmap_button.h"
 #include "no_flicker.h"
 #include "window_layout.h"
@@ -36,7 +36,7 @@ void setBestInitialSize(wxRichTextCtrl& ctrl, const wxString& text, wxSize maxSi
 
     const int rowGap = 0;
     int maxLineWidth = 0;
-    int rowHeight = 0;
+    int rowHeight = 0; //alternative: just call ctrl.GetCharHeight()!?
     int rowCount  = 0;
     bool haveLineWrap = false;
 
@@ -289,7 +289,7 @@ public:
         GetSizer()->SetSizeHints(this); //~=Fit() + SetMinSize()
 #ifdef __WXGTK3__
         Show(); //GTK3 size calculation requires visible window: https://github.com/wxWidgets/wxWidgets/issues/16088
-        Hide(); //avoid old position flash when Center() moves window (asynchronously?)
+        //Hide(); -> avoids old position flash before Center() on GNOME but causes hang on KDE? https://freefilesync.org/forum/viewtopic.php?t=10103#p42404
 #endif
         Center(); //needs to be re-applied after a dialog size change!
 
