@@ -5,7 +5,7 @@
 // *****************************************************************************
 
 #include "process_exec.h"
-#include <chrono>
+//#include <chrono>
 #include "guid.h"
 #include "file_access.h"
 #include "file_io.h"
@@ -69,7 +69,7 @@ std::pair<int /*exit code*/, std::string> processExecuteImpl(const Zstring& file
     const int fdTempFile = ::open(tempFilePath.c_str(), O_CREAT | O_EXCL | O_RDWR | O_CLOEXEC,
                                   S_IRUSR | S_IWUSR); //0600
     if (fdTempFile == -1)
-        THROW_LAST_SYS_ERROR("open");
+        THROW_LAST_SYS_ERROR("open(" + utfTo<std::string>(tempFilePath) + ")");
     auto guardTmpFile = makeGuard<ScopeGuardRunMode::onExit>([&] { ::close(fdTempFile); });
 
     //"deleting while handle is open" == FILE_FLAG_DELETE_ON_CLOSE
@@ -207,7 +207,7 @@ std::pair<int /*exit code*/, std::string> processExecuteImpl(const Zstring& file
         THROW_LAST_SYS_ERROR("lseek");
 
     guardTmpFile.dismiss();
-    FileInputPlain streamIn(fdTempFile, tempFilePath); //takes ownership!
+    FileInputPlain streamIn(fdTempFile, tempFilePath); //pass ownership!
 
     std::string output = unbufferedLoad<std::string>([&](void* buffer, size_t bytesToRead)
     {
