@@ -7,10 +7,11 @@
 #ifndef STREAM_BUFFER_H_08492572089560298
 #define STREAM_BUFFER_H_08492572089560298
 
-#include <condition_variable>
+#include <thread>
+//#include <condition_variable>
 #include "ring_buffer.h"
 #include "string_tools.h"
-#include "thread.h"
+//#include "thread.h"
 
 
 namespace zen
