@@ -8,6 +8,7 @@
 #define SYMLINK_TARGET_H_801783470198357483
 
 #include "file_error.h"
+#include "file_path.h"
 
     #include <unistd.h>
     #include <stdlib.h> //realpath
@@ -35,49 +36,61 @@ Zstring getSymlinkResolvedPath(const Zstring& linkPath); //throw FileError
 
 //################################ implementation ################################
 
+
+namespace zen
+{
 namespace
 {
 //retrieve raw target data of symlink or junction
-zen::SymlinkRawContent getSymlinkRawContent_impl(const Zstring& linkPath) //throw FileError
+SymlinkRawContent getSymlinkRawContent_impl(const Zstring& linkPath) //throw SysError
 {
-    using namespace zen;
     const size_t bufSize = 10000;
     std::vector<char> buf(bufSize);
 
     const ssize_t bytesWritten = ::readlink(linkPath.c_str(), buf.data(), bufSize);
     if (bytesWritten < 0)
-        THROW_LAST_FILE_ERROR(replaceCpy(_("Cannot resolve symbolic link %x."), L"%x", fmtPath(linkPath)), "readlink");
-    if (makeUnsigned(bytesWritten) >= bufSize) //detect truncation; not an error for readlink!
-        throw FileError(replaceCpy(_("Cannot resolve symbolic link %x."), L"%x", fmtPath(linkPath)), formatSystemError("readlink", L"", L"Buffer truncated."));
+        THROW_LAST_SYS_ERROR("readlink");
+
+    ASSERT_SYSERROR(makeUnsigned(bytesWritten) <= bufSize); //better safe than sorry
+
+    if (makeUnsigned(bytesWritten) == bufSize) //detect truncation; not an error for readlink!
+        throw SysError(formatSystemError("readlink", L"", L"Buffer truncated."));
 
     return {.targetPath = Zstring(buf.data(), bytesWritten)}; //readlink does not append 0-termination!
 }
 
 
-Zstring getResolvedSymlinkPath_impl(const Zstring& linkPath) //throw FileError
+Zstring getSymlinkResolvedPath_impl(const Zstring& linkPath) //throw SysError
+{
+    char* targetPath = ::realpath(linkPath.c_str(), nullptr);
+    if (!targetPath)
+        THROW_LAST_SYS_ERROR("realpath");
+    ZEN_ON_SCOPE_EXIT(::free(targetPath));
+    return targetPath;
+}
+}
+
+
+inline
+SymlinkRawContent getSymlinkRawContent(const Zstring& linkPath)
 {
-    using namespace zen;
     try
     {
-        char* targetPath = ::realpath(linkPath.c_str(), nullptr);
-        if (!targetPath)
-            THROW_LAST_SYS_ERROR("realpath");
-        ZEN_ON_SCOPE_EXIT(::free(targetPath));
-        return targetPath;
+        return getSymlinkRawContent_impl(linkPath); //throw SysError
+    }
+    catch (const SysError& e) { throw FileError(replaceCpy(_("Cannot resolve symbolic link %x."), L"%x", fmtPath(linkPath)), e.toString()); }
+}
+
+
+inline
+Zstring getSymlinkResolvedPath(const Zstring& linkPath)
+{
+    try
+    {
+        return getSymlinkResolvedPath_impl(linkPath); //throw SysError
     }
     catch (const SysError& e) { throw FileError(replaceCpy(_("Cannot determine final path for %x."), L"%x", fmtPath(linkPath)), e.toString()); }
 }
-}
-
-
-namespace zen
-{
-inline
-SymlinkRawContent getSymlinkRawContent(const Zstring& linkPath) { return getSymlinkRawContent_impl(linkPath); } //throw FileError
-
-
-inline
-Zstring getSymlinkResolvedPath(const Zstring& linkPath) { return getResolvedSymlinkPath_impl(linkPath); } //throw FileError
 
 }
 
