@@ -55,8 +55,8 @@ OsVersionDetail zen::getOsVersionDetail() //throw SysError
                 osVersion = utfTo<std::wstring>(afterFirst(line, '=', IfNotFoundReturn::none));
             //PRETTY_NAME? too wordy! e.g. "Fedora 17 (Beefy Miracle)"
         });
-        trim(osName,    true, true, [](char c) { return c == L'"' || c == L'\''; });
-        trim(osVersion, true, true, [](char c) { return c == L'"' || c == L'\''; });
+        trim(osName,    TrimSide::both, [](char c) { return c == L'"' || c == L'\''; });
+        trim(osVersion, TrimSide::both, [](char c) { return c == L'"' || c == L'\''; });
     }
 
     if (osName.empty())
@@ -89,8 +89,8 @@ OsVersion zen::getOsVersion()
         }
         catch (const SysError& e)
         {
-            std::cerr << utfTo<std::string>(e.toString()) + '\n';
-            return OsVersionDetail{}; //sigh, it's a jungle out there: https://freefilesync.org/forum/viewtopic.php?t=7276
+            logExtraError(_("Cannot get process information.") + L"\n\n" + e.toString());
+            return OsVersionDetail{}; //arrgh, it's a jungle out there: https://freefilesync.org/forum/viewtopic.php?t=7276
         }
     }();
     return verDetail.version;
